# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class Schema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'aliases': 'list[str]',
        'doc': 'str',
        'element_type': 'Schema',
        'enum_default': 'str',
        'enum_symbols': 'list[str]',
        'error': 'bool',
        'fields': 'list[Field]',
        'fixed_size': 'int',
        'full_name': 'str',
        'logical_type': 'LogicalType',
        'name': 'str',
        'namespace': 'str',
        'nullable': 'bool',
        'object_props': 'dict(str, object)',
        'type': 'str',
        'types': 'list[Schema]',
        'union': 'bool',
        'value_type': 'Schema'
    }

    attribute_map = {
        'aliases': 'aliases',
        'doc': 'doc',
        'element_type': 'elementType',
        'enum_default': 'enumDefault',
        'enum_symbols': 'enumSymbols',
        'error': 'error',
        'fields': 'fields',
        'fixed_size': 'fixedSize',
        'full_name': 'fullName',
        'logical_type': 'logicalType',
        'name': 'name',
        'namespace': 'namespace',
        'nullable': 'nullable',
        'object_props': 'objectProps',
        'type': 'type',
        'types': 'types',
        'union': 'union',
        'value_type': 'valueType'
    }

    def __init__(self, aliases=None, doc=None, element_type=None, enum_default=None, enum_symbols=None, error=None, fields=None, fixed_size=None, full_name=None, logical_type=None, name=None, namespace=None, nullable=None, object_props=None, type=None, types=None, union=None, value_type=None, _configuration=None):  # noqa: E501
        """Schema - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._aliases = None
        self._doc = None
        self._element_type = None
        self._enum_default = None
        self._enum_symbols = None
        self._error = None
        self._fields = None
        self._fixed_size = None
        self._full_name = None
        self._logical_type = None
        self._name = None
        self._namespace = None
        self._nullable = None
        self._object_props = None
        self._type = None
        self._types = None
        self._union = None
        self._value_type = None
        self.discriminator = None

        if aliases is not None:
            self.aliases = aliases
        if doc is not None:
            self.doc = doc
        if element_type is not None:
            self.element_type = element_type
        if enum_default is not None:
            self.enum_default = enum_default
        if enum_symbols is not None:
            self.enum_symbols = enum_symbols
        if error is not None:
            self.error = error
        if fields is not None:
            self.fields = fields
        if fixed_size is not None:
            self.fixed_size = fixed_size
        if full_name is not None:
            self.full_name = full_name
        if logical_type is not None:
            self.logical_type = logical_type
        if name is not None:
            self.name = name
        if namespace is not None:
            self.namespace = namespace
        if nullable is not None:
            self.nullable = nullable
        if object_props is not None:
            self.object_props = object_props
        if type is not None:
            self.type = type
        if types is not None:
            self.types = types
        if union is not None:
            self.union = union
        if value_type is not None:
            self.value_type = value_type

    @property
    def aliases(self):
        """Gets the aliases of this Schema.  # noqa: E501


        :return: The aliases of this Schema.  # noqa: E501
        :rtype: list[str]
        """
        return self._aliases

    @aliases.setter
    def aliases(self, aliases):
        """Sets the aliases of this Schema.


        :param aliases: The aliases of this Schema.  # noqa: E501
        :type: list[str]
        """

        self._aliases = aliases

    @property
    def doc(self):
        """Gets the doc of this Schema.  # noqa: E501


        :return: The doc of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._doc

    @doc.setter
    def doc(self, doc):
        """Sets the doc of this Schema.


        :param doc: The doc of this Schema.  # noqa: E501
        :type: str
        """

        self._doc = doc

    @property
    def element_type(self):
        """Gets the element_type of this Schema.  # noqa: E501


        :return: The element_type of this Schema.  # noqa: E501
        :rtype: Schema
        """
        return self._element_type

    @element_type.setter
    def element_type(self, element_type):
        """Sets the element_type of this Schema.


        :param element_type: The element_type of this Schema.  # noqa: E501
        :type: Schema
        """

        self._element_type = element_type

    @property
    def enum_default(self):
        """Gets the enum_default of this Schema.  # noqa: E501


        :return: The enum_default of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._enum_default

    @enum_default.setter
    def enum_default(self, enum_default):
        """Sets the enum_default of this Schema.


        :param enum_default: The enum_default of this Schema.  # noqa: E501
        :type: str
        """

        self._enum_default = enum_default

    @property
    def enum_symbols(self):
        """Gets the enum_symbols of this Schema.  # noqa: E501


        :return: The enum_symbols of this Schema.  # noqa: E501
        :rtype: list[str]
        """
        return self._enum_symbols

    @enum_symbols.setter
    def enum_symbols(self, enum_symbols):
        """Sets the enum_symbols of this Schema.


        :param enum_symbols: The enum_symbols of this Schema.  # noqa: E501
        :type: list[str]
        """

        self._enum_symbols = enum_symbols

    @property
    def error(self):
        """Gets the error of this Schema.  # noqa: E501


        :return: The error of this Schema.  # noqa: E501
        :rtype: bool
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this Schema.


        :param error: The error of this Schema.  # noqa: E501
        :type: bool
        """

        self._error = error

    @property
    def fields(self):
        """Gets the fields of this Schema.  # noqa: E501


        :return: The fields of this Schema.  # noqa: E501
        :rtype: list[Field]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this Schema.


        :param fields: The fields of this Schema.  # noqa: E501
        :type: list[Field]
        """

        self._fields = fields

    @property
    def fixed_size(self):
        """Gets the fixed_size of this Schema.  # noqa: E501


        :return: The fixed_size of this Schema.  # noqa: E501
        :rtype: int
        """
        return self._fixed_size

    @fixed_size.setter
    def fixed_size(self, fixed_size):
        """Sets the fixed_size of this Schema.


        :param fixed_size: The fixed_size of this Schema.  # noqa: E501
        :type: int
        """

        self._fixed_size = fixed_size

    @property
    def full_name(self):
        """Gets the full_name of this Schema.  # noqa: E501


        :return: The full_name of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this Schema.


        :param full_name: The full_name of this Schema.  # noqa: E501
        :type: str
        """

        self._full_name = full_name

    @property
    def logical_type(self):
        """Gets the logical_type of this Schema.  # noqa: E501


        :return: The logical_type of this Schema.  # noqa: E501
        :rtype: LogicalType
        """
        return self._logical_type

    @logical_type.setter
    def logical_type(self, logical_type):
        """Sets the logical_type of this Schema.


        :param logical_type: The logical_type of this Schema.  # noqa: E501
        :type: LogicalType
        """

        self._logical_type = logical_type

    @property
    def name(self):
        """Gets the name of this Schema.  # noqa: E501


        :return: The name of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Schema.


        :param name: The name of this Schema.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def namespace(self):
        """Gets the namespace of this Schema.  # noqa: E501


        :return: The namespace of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this Schema.


        :param namespace: The namespace of this Schema.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def nullable(self):
        """Gets the nullable of this Schema.  # noqa: E501


        :return: The nullable of this Schema.  # noqa: E501
        :rtype: bool
        """
        return self._nullable

    @nullable.setter
    def nullable(self, nullable):
        """Sets the nullable of this Schema.


        :param nullable: The nullable of this Schema.  # noqa: E501
        :type: bool
        """

        self._nullable = nullable

    @property
    def object_props(self):
        """Gets the object_props of this Schema.  # noqa: E501


        :return: The object_props of this Schema.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._object_props

    @object_props.setter
    def object_props(self, object_props):
        """Sets the object_props of this Schema.


        :param object_props: The object_props of this Schema.  # noqa: E501
        :type: dict(str, object)
        """

        self._object_props = object_props

    @property
    def type(self):
        """Gets the type of this Schema.  # noqa: E501


        :return: The type of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Schema.


        :param type: The type of this Schema.  # noqa: E501
        :type: str
        """
        allowed_values = ["RECORD", "ENUM", "ARRAY", "MAP", "UNION", "FIXED", "STRING", "BYTES", "INT", "LONG", "FLOAT", "DOUBLE", "BOOLEAN", "NULL"]  # noqa: E501
        if (self._configuration.client_side_validation and
                type not in allowed_values):
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def types(self):
        """Gets the types of this Schema.  # noqa: E501


        :return: The types of this Schema.  # noqa: E501
        :rtype: list[Schema]
        """
        return self._types

    @types.setter
    def types(self, types):
        """Sets the types of this Schema.


        :param types: The types of this Schema.  # noqa: E501
        :type: list[Schema]
        """

        self._types = types

    @property
    def union(self):
        """Gets the union of this Schema.  # noqa: E501


        :return: The union of this Schema.  # noqa: E501
        :rtype: bool
        """
        return self._union

    @union.setter
    def union(self, union):
        """Sets the union of this Schema.


        :param union: The union of this Schema.  # noqa: E501
        :type: bool
        """

        self._union = union

    @property
    def value_type(self):
        """Gets the value_type of this Schema.  # noqa: E501


        :return: The value_type of this Schema.  # noqa: E501
        :rtype: Schema
        """
        return self._value_type

    @value_type.setter
    def value_type(self, value_type):
        """Sets the value_type of this Schema.


        :param value_type: The value_type of this Schema.  # noqa: E501
        :type: Schema
        """

        self._value_type = value_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Schema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Schema):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Schema):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.usage_api import UsageApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestUsageApi(unittest.TestCase):
    """UsageApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.usage_api.UsageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_ingestion_policy(self):
        """Test case for create_ingestion_policy

        Create a specific ingestion policy  # noqa: E501
        """
        pass

    def test_delete_ingestion_policy(self):
        """Test case for delete_ingestion_policy

        Delete a specific ingestion policy  # noqa: E501
        """
        pass

    def test_export_csv(self):
        """Test case for export_csv

        Export a CSV report  # noqa: E501
        """
        pass

    def test_get_all_ingestion_policies(self):
        """Test case for get_all_ingestion_policies

        Get all ingestion policies for a customer  # noqa: E501
        """
        pass

    def test_get_ingestion_policy(self):
        """Test case for get_ingestion_policy

        Get a specific ingestion policy  # noqa: E501
        """
        pass

    def test_update_ingestion_policy(self):
        """Test case for update_ingestion_policy

        Update a specific ingestion policy  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class StatsModelInternalUse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'buffer_keys': 'int',
        'cached_compacted_keys': 'int',
        'compacted_keys': 'int',
        'compacted_points': 'int',
        'cpu_ns': 'int',
        'distributions': 'int',
        'edges': 'int',
        'hosts_used': 'int',
        'keys': 'int',
        'latency': 'int',
        'metrics': 'int',
        'metrics_used': 'int',
        'points': 'int',
        'queries': 'int',
        'query_tasks': 'int',
        's3_keys': 'int',
        'skipped_compacted_keys': 'int',
        'spans': 'int',
        'summaries': 'int'
    }

    attribute_map = {
        'buffer_keys': 'buffer_keys',
        'cached_compacted_keys': 'cached_compacted_keys',
        'compacted_keys': 'compacted_keys',
        'compacted_points': 'compacted_points',
        'cpu_ns': 'cpu_ns',
        'distributions': 'distributions',
        'edges': 'edges',
        'hosts_used': 'hosts_used',
        'keys': 'keys',
        'latency': 'latency',
        'metrics': 'metrics',
        'metrics_used': 'metrics_used',
        'points': 'points',
        'queries': 'queries',
        'query_tasks': 'query_tasks',
        's3_keys': 's3_keys',
        'skipped_compacted_keys': 'skipped_compacted_keys',
        'spans': 'spans',
        'summaries': 'summaries'
    }

    def __init__(self, buffer_keys=None, cached_compacted_keys=None, compacted_keys=None, compacted_points=None, cpu_ns=None, distributions=None, edges=None, hosts_used=None, keys=None, latency=None, metrics=None, metrics_used=None, points=None, queries=None, query_tasks=None, s3_keys=None, skipped_compacted_keys=None, spans=None, summaries=None, _configuration=None):  # noqa: E501
        """StatsModelInternalUse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._buffer_keys = None
        self._cached_compacted_keys = None
        self._compacted_keys = None
        self._compacted_points = None
        self._cpu_ns = None
        self._distributions = None
        self._edges = None
        self._hosts_used = None
        self._keys = None
        self._latency = None
        self._metrics = None
        self._metrics_used = None
        self._points = None
        self._queries = None
        self._query_tasks = None
        self._s3_keys = None
        self._skipped_compacted_keys = None
        self._spans = None
        self._summaries = None
        self.discriminator = None

        if buffer_keys is not None:
            self.buffer_keys = buffer_keys
        if cached_compacted_keys is not None:
            self.cached_compacted_keys = cached_compacted_keys
        if compacted_keys is not None:
            self.compacted_keys = compacted_keys
        if compacted_points is not None:
            self.compacted_points = compacted_points
        if cpu_ns is not None:
            self.cpu_ns = cpu_ns
        if distributions is not None:
            self.distributions = distributions
        if edges is not None:
            self.edges = edges
        if hosts_used is not None:
            self.hosts_used = hosts_used
        if keys is not None:
            self.keys = keys
        if latency is not None:
            self.latency = latency
        if metrics is not None:
            self.metrics = metrics
        if metrics_used is not None:
            self.metrics_used = metrics_used
        if points is not None:
            self.points = points
        if queries is not None:
            self.queries = queries
        if query_tasks is not None:
            self.query_tasks = query_tasks
        if s3_keys is not None:
            self.s3_keys = s3_keys
        if skipped_compacted_keys is not None:
            self.skipped_compacted_keys = skipped_compacted_keys
        if spans is not None:
            self.spans = spans
        if summaries is not None:
            self.summaries = summaries

    @property
    def buffer_keys(self):
        """Gets the buffer_keys of this StatsModelInternalUse.  # noqa: E501


        :return: The buffer_keys of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._buffer_keys

    @buffer_keys.setter
    def buffer_keys(self, buffer_keys):
        """Sets the buffer_keys of this StatsModelInternalUse.


        :param buffer_keys: The buffer_keys of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._buffer_keys = buffer_keys

    @property
    def cached_compacted_keys(self):
        """Gets the cached_compacted_keys of this StatsModelInternalUse.  # noqa: E501


        :return: The cached_compacted_keys of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._cached_compacted_keys

    @cached_compacted_keys.setter
    def cached_compacted_keys(self, cached_compacted_keys):
        """Sets the cached_compacted_keys of this StatsModelInternalUse.


        :param cached_compacted_keys: The cached_compacted_keys of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._cached_compacted_keys = cached_compacted_keys

    @property
    def compacted_keys(self):
        """Gets the compacted_keys of this StatsModelInternalUse.  # noqa: E501


        :return: The compacted_keys of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._compacted_keys

    @compacted_keys.setter
    def compacted_keys(self, compacted_keys):
        """Sets the compacted_keys of this StatsModelInternalUse.


        :param compacted_keys: The compacted_keys of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._compacted_keys = compacted_keys

    @property
    def compacted_points(self):
        """Gets the compacted_points of this StatsModelInternalUse.  # noqa: E501


        :return: The compacted_points of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._compacted_points

    @compacted_points.setter
    def compacted_points(self, compacted_points):
        """Sets the compacted_points of this StatsModelInternalUse.


        :param compacted_points: The compacted_points of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._compacted_points = compacted_points

    @property
    def cpu_ns(self):
        """Gets the cpu_ns of this StatsModelInternalUse.  # noqa: E501


        :return: The cpu_ns of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._cpu_ns

    @cpu_ns.setter
    def cpu_ns(self, cpu_ns):
        """Sets the cpu_ns of this StatsModelInternalUse.


        :param cpu_ns: The cpu_ns of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._cpu_ns = cpu_ns

    @property
    def distributions(self):
        """Gets the distributions of this StatsModelInternalUse.  # noqa: E501


        :return: The distributions of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._distributions

    @distributions.setter
    def distributions(self, distributions):
        """Sets the distributions of this StatsModelInternalUse.


        :param distributions: The distributions of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._distributions = distributions

    @property
    def edges(self):
        """Gets the edges of this StatsModelInternalUse.  # noqa: E501


        :return: The edges of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this StatsModelInternalUse.


        :param edges: The edges of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._edges = edges

    @property
    def hosts_used(self):
        """Gets the hosts_used of this StatsModelInternalUse.  # noqa: E501


        :return: The hosts_used of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._hosts_used

    @hosts_used.setter
    def hosts_used(self, hosts_used):
        """Sets the hosts_used of this StatsModelInternalUse.


        :param hosts_used: The hosts_used of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._hosts_used = hosts_used

    @property
    def keys(self):
        """Gets the keys of this StatsModelInternalUse.  # noqa: E501


        :return: The keys of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._keys

    @keys.setter
    def keys(self, keys):
        """Sets the keys of this StatsModelInternalUse.


        :param keys: The keys of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._keys = keys

    @property
    def latency(self):
        """Gets the latency of this StatsModelInternalUse.  # noqa: E501


        :return: The latency of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._latency

    @latency.setter
    def latency(self, latency):
        """Sets the latency of this StatsModelInternalUse.


        :param latency: The latency of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._latency = latency

    @property
    def metrics(self):
        """Gets the metrics of this StatsModelInternalUse.  # noqa: E501


        :return: The metrics of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """Sets the metrics of this StatsModelInternalUse.


        :param metrics: The metrics of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._metrics = metrics

    @property
    def metrics_used(self):
        """Gets the metrics_used of this StatsModelInternalUse.  # noqa: E501


        :return: The metrics_used of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._metrics_used

    @metrics_used.setter
    def metrics_used(self, metrics_used):
        """Sets the metrics_used of this StatsModelInternalUse.


        :param metrics_used: The metrics_used of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._metrics_used = metrics_used

    @property
    def points(self):
        """Gets the points of this StatsModelInternalUse.  # noqa: E501


        :return: The points of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this StatsModelInternalUse.


        :param points: The points of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._points = points

    @property
    def queries(self):
        """Gets the queries of this StatsModelInternalUse.  # noqa: E501


        :return: The queries of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._queries

    @queries.setter
    def queries(self, queries):
        """Sets the queries of this StatsModelInternalUse.


        :param queries: The queries of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._queries = queries

    @property
    def query_tasks(self):
        """Gets the query_tasks of this StatsModelInternalUse.  # noqa: E501


        :return: The query_tasks of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._query_tasks

    @query_tasks.setter
    def query_tasks(self, query_tasks):
        """Sets the query_tasks of this StatsModelInternalUse.


        :param query_tasks: The query_tasks of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._query_tasks = query_tasks

    @property
    def s3_keys(self):
        """Gets the s3_keys of this StatsModelInternalUse.  # noqa: E501


        :return: The s3_keys of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._s3_keys

    @s3_keys.setter
    def s3_keys(self, s3_keys):
        """Sets the s3_keys of this StatsModelInternalUse.


        :param s3_keys: The s3_keys of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._s3_keys = s3_keys

    @property
    def skipped_compacted_keys(self):
        """Gets the skipped_compacted_keys of this StatsModelInternalUse.  # noqa: E501


        :return: The skipped_compacted_keys of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._skipped_compacted_keys

    @skipped_compacted_keys.setter
    def skipped_compacted_keys(self, skipped_compacted_keys):
        """Sets the skipped_compacted_keys of this StatsModelInternalUse.


        :param skipped_compacted_keys: The skipped_compacted_keys of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._skipped_compacted_keys = skipped_compacted_keys

    @property
    def spans(self):
        """Gets the spans of this StatsModelInternalUse.  # noqa: E501


        :return: The spans of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._spans

    @spans.setter
    def spans(self, spans):
        """Sets the spans of this StatsModelInternalUse.


        :param spans: The spans of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._spans = spans

    @property
    def summaries(self):
        """Gets the summaries of this StatsModelInternalUse.  # noqa: E501


        :return: The summaries of this StatsModelInternalUse.  # noqa: E501
        :rtype: int
        """
        return self._summaries

    @summaries.setter
    def summaries(self, summaries):
        """Sets the summaries of this StatsModelInternalUse.


        :param summaries: The summaries of this StatsModelInternalUse.  # noqa: E501
        :type: int
        """

        self._summaries = summaries

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StatsModelInternalUse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatsModelInternalUse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StatsModelInternalUse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class EventSearchRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cursor': 'str',
        'limit': 'int',
        'query': 'list[SearchQuery]',
        'related_event_time_range': 'RelatedEventTimeRange',
        'sort_score_method': 'str',
        'sort_time_ascending': 'bool',
        'time_range': 'EventTimeRange'
    }

    attribute_map = {
        'cursor': 'cursor',
        'limit': 'limit',
        'query': 'query',
        'related_event_time_range': 'relatedEventTimeRange',
        'sort_score_method': 'sortScoreMethod',
        'sort_time_ascending': 'sortTimeAscending',
        'time_range': 'timeRange'
    }

    def __init__(self, cursor=None, limit=None, query=None, related_event_time_range=None, sort_score_method=None, sort_time_ascending=None, time_range=None, _configuration=None):  # noqa: E501
        """EventSearchRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cursor = None
        self._limit = None
        self._query = None
        self._related_event_time_range = None
        self._sort_score_method = None
        self._sort_time_ascending = None
        self._time_range = None
        self.discriminator = None

        if cursor is not None:
            self.cursor = cursor
        if limit is not None:
            self.limit = limit
        if query is not None:
            self.query = query
        if related_event_time_range is not None:
            self.related_event_time_range = related_event_time_range
        if sort_score_method is not None:
            self.sort_score_method = sort_score_method
        if sort_time_ascending is not None:
            self.sort_time_ascending = sort_time_ascending
        if time_range is not None:
            self.time_range = time_range

    @property
    def cursor(self):
        """Gets the cursor of this EventSearchRequest.  # noqa: E501

        The id (exclusive) from which search results resume returning.  Users should supply an entity 'id' to this property.  Its main purpose is to resume where a previous search left off because of the 'limit' parameter.  If a user supplies the last id in a set of results to cursor, while keeping the query the same, the system will return the next page of results  # noqa: E501

        :return: The cursor of this EventSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._cursor

    @cursor.setter
    def cursor(self, cursor):
        """Sets the cursor of this EventSearchRequest.

        The id (exclusive) from which search results resume returning.  Users should supply an entity 'id' to this property.  Its main purpose is to resume where a previous search left off because of the 'limit' parameter.  If a user supplies the last id in a set of results to cursor, while keeping the query the same, the system will return the next page of results  # noqa: E501

        :param cursor: The cursor of this EventSearchRequest.  # noqa: E501
        :type: str
        """

        self._cursor = cursor

    @property
    def limit(self):
        """Gets the limit of this EventSearchRequest.  # noqa: E501

        The number of results to return.  Default: 100  # noqa: E501

        :return: The limit of this EventSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this EventSearchRequest.

        The number of results to return.  Default: 100  # noqa: E501

        :param limit: The limit of this EventSearchRequest.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def query(self):
        """Gets the query of this EventSearchRequest.  # noqa: E501

        A list of queries by which to limit the search results  # noqa: E501

        :return: The query of this EventSearchRequest.  # noqa: E501
        :rtype: list[SearchQuery]
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this EventSearchRequest.

        A list of queries by which to limit the search results  # noqa: E501

        :param query: The query of this EventSearchRequest.  # noqa: E501
        :type: list[SearchQuery]
        """

        self._query = query

    @property
    def related_event_time_range(self):
        """Gets the related_event_time_range of this EventSearchRequest.  # noqa: E501


        :return: The related_event_time_range of this EventSearchRequest.  # noqa: E501
        :rtype: RelatedEventTimeRange
        """
        return self._related_event_time_range

    @related_event_time_range.setter
    def related_event_time_range(self, related_event_time_range):
        """Sets the related_event_time_range of this EventSearchRequest.


        :param related_event_time_range: The related_event_time_range of this EventSearchRequest.  # noqa: E501
        :type: RelatedEventTimeRange
        """

        self._related_event_time_range = related_event_time_range

    @property
    def sort_score_method(self):
        """Gets the sort_score_method of this EventSearchRequest.  # noqa: E501

        Whether to sort events on similarity score : {NONE, SCORE_ASC, SCORE_DES}. Default: NONE. If sortScoreMethod is set to SCORE_ASC or SCORE_DES, it will override time sort  # noqa: E501

        :return: The sort_score_method of this EventSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._sort_score_method

    @sort_score_method.setter
    def sort_score_method(self, sort_score_method):
        """Sets the sort_score_method of this EventSearchRequest.

        Whether to sort events on similarity score : {NONE, SCORE_ASC, SCORE_DES}. Default: NONE. If sortScoreMethod is set to SCORE_ASC or SCORE_DES, it will override time sort  # noqa: E501

        :param sort_score_method: The sort_score_method of this EventSearchRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["SCORE_ASC", "SCORE_DES", "NONE"]  # noqa: E501
        if (self._configuration.client_side_validation and
                sort_score_method not in allowed_values):
            raise ValueError(
                "Invalid value for `sort_score_method` ({0}), must be one of {1}"  # noqa: E501
                .format(sort_score_method, allowed_values)
            )

        self._sort_score_method = sort_score_method

    @property
    def sort_time_ascending(self):
        """Gets the sort_time_ascending of this EventSearchRequest.  # noqa: E501

        Whether to sort event results ascending in start time.  Default: false  # noqa: E501

        :return: The sort_time_ascending of this EventSearchRequest.  # noqa: E501
        :rtype: bool
        """
        return self._sort_time_ascending

    @sort_time_ascending.setter
    def sort_time_ascending(self, sort_time_ascending):
        """Sets the sort_time_ascending of this EventSearchRequest.

        Whether to sort event results ascending in start time.  Default: false  # noqa: E501

        :param sort_time_ascending: The sort_time_ascending of this EventSearchRequest.  # noqa: E501
        :type: bool
        """

        self._sort_time_ascending = sort_time_ascending

    @property
    def time_range(self):
        """Gets the time_range of this EventSearchRequest.  # noqa: E501


        :return: The time_range of this EventSearchRequest.  # noqa: E501
        :rtype: EventTimeRange
        """
        return self._time_range

    @time_range.setter
    def time_range(self, time_range):
        """Sets the time_range of this EventSearchRequest.


        :param time_range: The time_range of this EventSearchRequest.  # noqa: E501
        :type: EventTimeRange
        """

        self._time_range = time_range

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EventSearchRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventSearchRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EventSearchRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.event_api import EventApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestEventApi(unittest.TestCase):
    """EventApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.event_api.EventApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_event_tag(self):
        """Test case for add_event_tag

        Add a tag to a specific event  # noqa: E501
        """
        pass

    def test_close_event(self):
        """Test case for close_event

        Close a specific event  # noqa: E501
        """
        pass

    def test_create_event(self):
        """Test case for create_event

        Create a specific event  # noqa: E501
        """
        pass

    def test_delete_event(self):
        """Test case for delete_event

        Delete a specific event  # noqa: E501
        """
        pass

    def test_get_alert_event_queries_slug(self):
        """Test case for get_alert_event_queries_slug

        If the specified event is associated with an alert, returns a slug encoding the queries having to do with that alert firing or resolution  # noqa: E501
        """
        pass

    def test_get_alert_firing_details(self):
        """Test case for get_alert_firing_details

        Return details of a particular alert firing, including all the series that fired during the referred alert firing  # noqa: E501
        """
        pass

    def test_get_alert_firing_events(self):
        """Test case for get_alert_firing_events

        Get firings events of an alert within a time range  # noqa: E501
        """
        pass

    def test_get_all_events_with_time_range(self):
        """Test case for get_all_events_with_time_range

        List all the events for a customer within a time range  # noqa: E501
        """
        pass

    def test_get_event(self):
        """Test case for get_event

        Get a specific event  # noqa: E501
        """
        pass

    def test_get_event_tags(self):
        """Test case for get_event_tags

        Get all tags associated with a specific event  # noqa: E501
        """
        pass

    def test_get_related_events_with_time_span(self):
        """Test case for get_related_events_with_time_span

        List all related events for a specific firing event with a time span of one hour  # noqa: E501
        """
        pass

    def test_remove_event_tag(self):
        """Test case for remove_event_tag

        Remove a tag from a specific event  # noqa: E501
        """
        pass

    def test_set_event_tags(self):
        """Test case for set_event_tags

        Set all tags associated with a specific event  # noqa: E501
        """
        pass

    def test_update_event(self):
        """Test case for update_event

        Update a specific event  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class QueryTypeDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'input_query': 'str',
        'query_type': 'str',
        'translated_input': 'str'
    }

    attribute_map = {
        'input_query': 'inputQuery',
        'query_type': 'queryType',
        'translated_input': 'translatedInput'
    }

    def __init__(self, input_query=None, query_type=None, translated_input=None, _configuration=None):  # noqa: E501
        """QueryTypeDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._input_query = None
        self._query_type = None
        self._translated_input = None
        self.discriminator = None

        if input_query is not None:
            self.input_query = input_query
        if query_type is not None:
            self.query_type = query_type
        if translated_input is not None:
            self.translated_input = translated_input

    @property
    def input_query(self):
        """Gets the input_query of this QueryTypeDTO.  # noqa: E501


        :return: The input_query of this QueryTypeDTO.  # noqa: E501
        :rtype: str
        """
        return self._input_query

    @input_query.setter
    def input_query(self, input_query):
        """Sets the input_query of this QueryTypeDTO.


        :param input_query: The input_query of this QueryTypeDTO.  # noqa: E501
        :type: str
        """

        self._input_query = input_query

    @property
    def query_type(self):
        """Gets the query_type of this QueryTypeDTO.  # noqa: E501


        :return: The query_type of this QueryTypeDTO.  # noqa: E501
        :rtype: str
        """
        return self._query_type

    @query_type.setter
    def query_type(self, query_type):
        """Sets the query_type of this QueryTypeDTO.


        :param query_type: The query_type of this QueryTypeDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["WQL", "PROMQL", "HYBRID"]  # noqa: E501
        if (self._configuration.client_side_validation and
                query_type not in allowed_values):
            raise ValueError(
                "Invalid value for `query_type` ({0}), must be one of {1}"  # noqa: E501
                .format(query_type, allowed_values)
            )

        self._query_type = query_type

    @property
    def translated_input(self):
        """Gets the translated_input of this QueryTypeDTO.  # noqa: E501


        :return: The translated_input of this QueryTypeDTO.  # noqa: E501
        :rtype: str
        """
        return self._translated_input

    @translated_input.setter
    def translated_input(self, translated_input):
        """Sets the translated_input of this QueryTypeDTO.


        :param translated_input: The translated_input of this QueryTypeDTO.  # noqa: E501
        :type: str
        """

        self._translated_input = translated_input

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(QueryTypeDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryTypeDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueryTypeDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.account__user_and_service_account_api import AccountUserAndServiceAccountApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestAccountUserAndServiceAccountApi(unittest.TestCase):
    """AccountUserAndServiceAccountApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.account__user_and_service_account_api.AccountUserAndServiceAccountApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_account(self):
        """Test case for activate_account

        Activates the given service account  # noqa: E501
        """
        pass

    def test_add_account_to_roles(self):
        """Test case for add_account_to_roles

        Adds specific roles to the account (user or service account)  # noqa: E501
        """
        pass

    def test_add_account_to_user_groups(self):
        """Test case for add_account_to_user_groups

        Adds specific user groups to the account (user or service account)  # noqa: E501
        """
        pass

    def test_add_ingestion_policy(self):
        """Test case for add_ingestion_policy

        Add a specific ingestion policy to multiple accounts  # noqa: E501
        """
        pass

    def test_create_or_update_user_account(self):
        """Test case for create_or_update_user_account

        Creates or updates a user account  # noqa: E501
        """
        pass

    def test_create_service_account(self):
        """Test case for create_service_account

        Creates a service account  # noqa: E501
        """
        pass

    def test_deactivate_account(self):
        """Test case for deactivate_account

        Deactivates the given service account  # noqa: E501
        """
        pass

    def test_delete_account(self):
        """Test case for delete_account

        Deletes an account (user or service account) identified by id  # noqa: E501
        """
        pass

    def test_delete_multiple_accounts(self):
        """Test case for delete_multiple_accounts

        Deletes multiple accounts (users or service accounts)  # noqa: E501
        """
        pass

    def test_get_account(self):
        """Test case for get_account

        Get a specific account (user or service account)  # noqa: E501
        """
        pass

    def test_get_account_business_functions(self):
        """Test case for get_account_business_functions

        Returns business functions of a specific account (user or service account).  # noqa: E501
        """
        pass

    def test_get_all_accounts(self):
        """Test case for get_all_accounts

        Get all accounts (users and service accounts) of a customer  # noqa: E501
        """
        pass

    def test_get_all_service_accounts(self):
        """Test case for get_all_service_accounts

        Get all service accounts  # noqa: E501
        """
        pass

    def test_get_all_user_accounts(self):
        """Test case for get_all_user_accounts

        Get all user accounts  # noqa: E501
        """
        pass

    def test_get_service_account(self):
        """Test case for get_service_account

        Retrieves a service account by identifier  # noqa: E501
        """
        pass

    def test_get_user_account(self):
        """Test case for get_user_account

        Retrieves a user by identifier (email address)  # noqa: E501
        """
        pass

    def test_grant_account_permission(self):
        """Test case for grant_account_permission

        Grants a specific permission to account (user or service account)  # noqa: E501
        """
        pass

    def test_grant_permission_to_accounts(self):
        """Test case for grant_permission_to_accounts

        Grants a specific permission to multiple accounts (users or service accounts)  # noqa: E501
        """
        pass

    def test_invite_user_accounts(self):
        """Test case for invite_user_accounts

        Invite user accounts with given user groups and permissions.  # noqa: E501
        """
        pass

    def test_remove_account_from_roles(self):
        """Test case for remove_account_from_roles

        Removes specific roles from the account (user or service account)  # noqa: E501
        """
        pass

    def test_remove_account_from_user_groups(self):
        """Test case for remove_account_from_user_groups

        Removes specific user groups from the account (user or service account)  # noqa: E501
        """
        pass

    def test_remove_ingestion_policies(self):
        """Test case for remove_ingestion_policies

        Removes ingestion policies from multiple accounts  # noqa: E501
        """
        pass

    def test_revoke_account_permission(self):
        """Test case for revoke_account_permission

        Revokes a specific permission from account (user or service account)  # noqa: E501
        """
        pass

    def test_revoke_permission_from_accounts(self):
        """Test case for revoke_permission_from_accounts

        Revokes a specific permission from multiple accounts (users or service accounts)  # noqa: E501
        """
        pass

    def test_update_service_account(self):
        """Test case for update_service_account

        Updates the service account  # noqa: E501
        """
        pass

    def test_update_user_account(self):
        """Test case for update_user_account

        Update user with given user groups, permissions and ingestion policy.  # noqa: E501
        """
        pass

    def test_validate_accounts(self):
        """Test case for validate_accounts

        Returns valid accounts (users and service accounts), also invalid identifiers from the given list  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class IngestionPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'customer': 'str',
        'description': 'str',
        'id': 'str',
        'last_updated_account_id': 'str',
        'last_updated_ms': 'int',
        'name': 'str',
        'sampled_service_accounts': 'list[str]',
        'sampled_user_accounts': 'list[str]',
        'service_account_count': 'int',
        'user_account_count': 'int'
    }

    attribute_map = {
        'customer': 'customer',
        'description': 'description',
        'id': 'id',
        'last_updated_account_id': 'lastUpdatedAccountId',
        'last_updated_ms': 'lastUpdatedMs',
        'name': 'name',
        'sampled_service_accounts': 'sampledServiceAccounts',
        'sampled_user_accounts': 'sampledUserAccounts',
        'service_account_count': 'serviceAccountCount',
        'user_account_count': 'userAccountCount'
    }

    def __init__(self, customer=None, description=None, id=None, last_updated_account_id=None, last_updated_ms=None, name=None, sampled_service_accounts=None, sampled_user_accounts=None, service_account_count=None, user_account_count=None, _configuration=None):  # noqa: E501
        """IngestionPolicy - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._customer = None
        self._description = None
        self._id = None
        self._last_updated_account_id = None
        self._last_updated_ms = None
        self._name = None
        self._sampled_service_accounts = None
        self._sampled_user_accounts = None
        self._service_account_count = None
        self._user_account_count = None
        self.discriminator = None

        if customer is not None:
            self.customer = customer
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if last_updated_account_id is not None:
            self.last_updated_account_id = last_updated_account_id
        if last_updated_ms is not None:
            self.last_updated_ms = last_updated_ms
        if name is not None:
            self.name = name
        if sampled_service_accounts is not None:
            self.sampled_service_accounts = sampled_service_accounts
        if sampled_user_accounts is not None:
            self.sampled_user_accounts = sampled_user_accounts
        if service_account_count is not None:
            self.service_account_count = service_account_count
        if user_account_count is not None:
            self.user_account_count = user_account_count

    @property
    def customer(self):
        """Gets the customer of this IngestionPolicy.  # noqa: E501

        ID of the customer to which the ingestion policy belongs  # noqa: E501

        :return: The customer of this IngestionPolicy.  # noqa: E501
        :rtype: str
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this IngestionPolicy.

        ID of the customer to which the ingestion policy belongs  # noqa: E501

        :param customer: The customer of this IngestionPolicy.  # noqa: E501
        :type: str
        """

        self._customer = customer

    @property
    def description(self):
        """Gets the description of this IngestionPolicy.  # noqa: E501

        The description of the ingestion policy  # noqa: E501

        :return: The description of this IngestionPolicy.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this IngestionPolicy.

        The description of the ingestion policy  # noqa: E501

        :param description: The description of this IngestionPolicy.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this IngestionPolicy.  # noqa: E501

        The unique ID for the ingestion policy  # noqa: E501

        :return: The id of this IngestionPolicy.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IngestionPolicy.

        The unique ID for the ingestion policy  # noqa: E501

        :param id: The id of this IngestionPolicy.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def last_updated_account_id(self):
        """Gets the last_updated_account_id of this IngestionPolicy.  # noqa: E501

        The account that updated this ingestion policy last time  # noqa: E501

        :return: The last_updated_account_id of this IngestionPolicy.  # noqa: E501
        :rtype: str
        """
        return self._last_updated_account_id

    @last_updated_account_id.setter
    def last_updated_account_id(self, last_updated_account_id):
        """Sets the last_updated_account_id of this IngestionPolicy.

        The account that updated this ingestion policy last time  # noqa: E501

        :param last_updated_account_id: The last_updated_account_id of this IngestionPolicy.  # noqa: E501
        :type: str
        """

        self._last_updated_account_id = last_updated_account_id

    @property
    def last_updated_ms(self):
        """Gets the last_updated_ms of this IngestionPolicy.  # noqa: E501

        The last time when the ingestion policy is updated, in epoch milliseconds  # noqa: E501

        :return: The last_updated_ms of this IngestionPolicy.  # noqa: E501
        :rtype: int
        """
        return self._last_updated_ms

    @last_updated_ms.setter
    def last_updated_ms(self, last_updated_ms):
        """Sets the last_updated_ms of this IngestionPolicy.

        The last time when the ingestion policy is updated, in epoch milliseconds  # noqa: E501

        :param last_updated_ms: The last_updated_ms of this IngestionPolicy.  # noqa: E501
        :type: int
        """

        self._last_updated_ms = last_updated_ms

    @property
    def name(self):
        """Gets the name of this IngestionPolicy.  # noqa: E501

        The name of the ingestion policy  # noqa: E501

        :return: The name of this IngestionPolicy.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IngestionPolicy.

        The name of the ingestion policy  # noqa: E501

        :param name: The name of this IngestionPolicy.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def sampled_service_accounts(self):
        """Gets the sampled_service_accounts of this IngestionPolicy.  # noqa: E501

        A sample of the service accounts accounts assigned to this ingestion policy. Please use the Ingestion Policy facet of the Account Search API to get the full list of service accounts for this policy  # noqa: E501

        :return: The sampled_service_accounts of this IngestionPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._sampled_service_accounts

    @sampled_service_accounts.setter
    def sampled_service_accounts(self, sampled_service_accounts):
        """Sets the sampled_service_accounts of this IngestionPolicy.

        A sample of the service accounts accounts assigned to this ingestion policy. Please use the Ingestion Policy facet of the Account Search API to get the full list of service accounts for this policy  # noqa: E501

        :param sampled_service_accounts: The sampled_service_accounts of this IngestionPolicy.  # noqa: E501
        :type: list[str]
        """

        self._sampled_service_accounts = sampled_service_accounts

    @property
    def sampled_user_accounts(self):
        """Gets the sampled_user_accounts of this IngestionPolicy.  # noqa: E501

        A sample of the user accounts assigned to this ingestion policy. Please use the Ingestion Policy facet of the Account Search API to get the full list of users for this policy  # noqa: E501

        :return: The sampled_user_accounts of this IngestionPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._sampled_user_accounts

    @sampled_user_accounts.setter
    def sampled_user_accounts(self, sampled_user_accounts):
        """Sets the sampled_user_accounts of this IngestionPolicy.

        A sample of the user accounts assigned to this ingestion policy. Please use the Ingestion Policy facet of the Account Search API to get the full list of users for this policy  # noqa: E501

        :param sampled_user_accounts: The sampled_user_accounts of this IngestionPolicy.  # noqa: E501
        :type: list[str]
        """

        self._sampled_user_accounts = sampled_user_accounts

    @property
    def service_account_count(self):
        """Gets the service_account_count of this IngestionPolicy.  # noqa: E501

        Total number of service accounts that are linked to the ingestion policy  # noqa: E501

        :return: The service_account_count of this IngestionPolicy.  # noqa: E501
        :rtype: int
        """
        return self._service_account_count

    @service_account_count.setter
    def service_account_count(self, service_account_count):
        """Sets the service_account_count of this IngestionPolicy.

        Total number of service accounts that are linked to the ingestion policy  # noqa: E501

        :param service_account_count: The service_account_count of this IngestionPolicy.  # noqa: E501
        :type: int
        """

        self._service_account_count = service_account_count

    @property
    def user_account_count(self):
        """Gets the user_account_count of this IngestionPolicy.  # noqa: E501

        Total number of user accounts that are linked to the ingestion policy  # noqa: E501

        :return: The user_account_count of this IngestionPolicy.  # noqa: E501
        :rtype: int
        """
        return self._user_account_count

    @user_account_count.setter
    def user_account_count(self, user_account_count):
        """Sets the user_account_count of this IngestionPolicy.

        Total number of user accounts that are linked to the ingestion policy  # noqa: E501

        :param user_account_count: The user_account_count of this IngestionPolicy.  # noqa: E501
        :type: int
        """

        self._user_account_count = user_account_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IngestionPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IngestionPolicy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IngestionPolicy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class IntegrationManifestGroup(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'integration_objs': 'list[Integration]',
        'integrations': 'list[str]',
        'subtitle': 'str',
        'title': 'str'
    }

    attribute_map = {
        'integration_objs': 'integrationObjs',
        'integrations': 'integrations',
        'subtitle': 'subtitle',
        'title': 'title'
    }

    def __init__(self, integration_objs=None, integrations=None, subtitle=None, title=None, _configuration=None):  # noqa: E501
        """IntegrationManifestGroup - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._integration_objs = None
        self._integrations = None
        self._subtitle = None
        self._title = None
        self.discriminator = None

        if integration_objs is not None:
            self.integration_objs = integration_objs
        self.integrations = integrations
        self.subtitle = subtitle
        self.title = title

    @property
    def integration_objs(self):
        """Gets the integration_objs of this IntegrationManifestGroup.  # noqa: E501

        Materialized JSONs for integrations belonging to this group, as referenced by `integrations`  # noqa: E501

        :return: The integration_objs of this IntegrationManifestGroup.  # noqa: E501
        :rtype: list[Integration]
        """
        return self._integration_objs

    @integration_objs.setter
    def integration_objs(self, integration_objs):
        """Sets the integration_objs of this IntegrationManifestGroup.

        Materialized JSONs for integrations belonging to this group, as referenced by `integrations`  # noqa: E501

        :param integration_objs: The integration_objs of this IntegrationManifestGroup.  # noqa: E501
        :type: list[Integration]
        """

        self._integration_objs = integration_objs

    @property
    def integrations(self):
        """Gets the integrations of this IntegrationManifestGroup.  # noqa: E501

        A list of paths to JSON definitions for integrations in this group  # noqa: E501

        :return: The integrations of this IntegrationManifestGroup.  # noqa: E501
        :rtype: list[str]
        """
        return self._integrations

    @integrations.setter
    def integrations(self, integrations):
        """Sets the integrations of this IntegrationManifestGroup.

        A list of paths to JSON definitions for integrations in this group  # noqa: E501

        :param integrations: The integrations of this IntegrationManifestGroup.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and integrations is None:
            raise ValueError("Invalid value for `integrations`, must not be `None`")  # noqa: E501

        self._integrations = integrations

    @property
    def subtitle(self):
        """Gets the subtitle of this IntegrationManifestGroup.  # noqa: E501

        Subtitle of this integration group  # noqa: E501

        :return: The subtitle of this IntegrationManifestGroup.  # noqa: E501
        :rtype: str
        """
        return self._subtitle

    @subtitle.setter
    def subtitle(self, subtitle):
        """Sets the subtitle of this IntegrationManifestGroup.

        Subtitle of this integration group  # noqa: E501

        :param subtitle: The subtitle of this IntegrationManifestGroup.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and subtitle is None:
            raise ValueError("Invalid value for `subtitle`, must not be `None`")  # noqa: E501

        self._subtitle = subtitle

    @property
    def title(self):
        """Gets the title of this IntegrationManifestGroup.  # noqa: E501

        Title of this integration group  # noqa: E501

        :return: The title of this IntegrationManifestGroup.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this IntegrationManifestGroup.

        Title of this integration group  # noqa: E501

        :param title: The title of this IntegrationManifestGroup.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IntegrationManifestGroup, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntegrationManifestGroup):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IntegrationManifestGroup):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.message_api import MessageApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestMessageApi(unittest.TestCase):
    """MessageApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.message_api.MessageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_user_get_messages(self):
        """Test case for user_get_messages

        Gets messages applicable to the current user, i.e. within time range and distribution scope  # noqa: E501
        """
        pass

    def test_user_read_message(self):
        """Test case for user_read_message

        Mark a specific message as read  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wavefront_api_client.api_client import ApiClient


class EventApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_event_tag(self, id, tag_value, **kwargs):  # noqa: E501
        """Add a tag to a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_event_tag(id, tag_value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str tag_value: (required)
        :return: ResponseContainer
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_event_tag_with_http_info(id, tag_value, **kwargs)  # noqa: E501
        else:
            (data) = self.add_event_tag_with_http_info(id, tag_value, **kwargs)  # noqa: E501
            return data

    def add_event_tag_with_http_info(self, id, tag_value, **kwargs):  # noqa: E501
        """Add a tag to a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_event_tag_with_http_info(id, tag_value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str tag_value: (required)
        :return: ResponseContainer
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'tag_value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_event_tag" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `add_event_tag`")  # noqa: E501
        # verify the required parameter 'tag_value' is set
        if self.api_client.client_side_validation and ('tag_value' not in params or
                                                       params['tag_value'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tag_value` when calling `add_event_tag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'tag_value' in params:
            path_params['tagValue'] = params['tag_value']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event/{id}/tag/{tagValue}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainer',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def close_event(self, id, **kwargs):  # noqa: E501
        """Close a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.close_event(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.close_event_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.close_event_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def close_event_with_http_info(self, id, **kwargs):  # noqa: E501
        """Close a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.close_event_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method close_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `close_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event/{id}/close', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerEvent',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_event(self, **kwargs):  # noqa: E501
        """Create a specific event  # noqa: E501

        The following fields are readonly and will be ignored when passed in the request: <code>id</code>, <code>isEphemeral</code>, <code>isUserEvent</code>, <code>runningState</code>, <code>canDelete</code>, <code>canClose</code>, <code>creatorType</code>, <code>createdAt</code>, <code>updatedAt</code>, <code>createdEpochMillis</code>, <code>updatedEpochMillis</code>, <code>updaterId</code>, <code>creatorId</code>, and <code>summarizedEvents</code>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_event(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Event body: Example Body:  <pre>{   \"name\": \"Event API Example\",   \"annotations\": {     \"severity\": \"info\",     \"type\": \"event type\",     \"details\": \"description\"   },   \"tags\" : [     \"eventTag1\"   ],   \"startTime\": 1490000000000,   \"endTime\": 1490000000001 }</pre>
        :return: ResponseContainerEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_event_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_event_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_event_with_http_info(self, **kwargs):  # noqa: E501
        """Create a specific event  # noqa: E501

        The following fields are readonly and will be ignored when passed in the request: <code>id</code>, <code>isEphemeral</code>, <code>isUserEvent</code>, <code>runningState</code>, <code>canDelete</code>, <code>canClose</code>, <code>creatorType</code>, <code>createdAt</code>, <code>updatedAt</code>, <code>createdEpochMillis</code>, <code>updatedEpochMillis</code>, <code>updaterId</code>, <code>creatorId</code>, and <code>summarizedEvents</code>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_event_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Event body: Example Body:  <pre>{   \"name\": \"Event API Example\",   \"annotations\": {     \"severity\": \"info\",     \"type\": \"event type\",     \"details\": \"description\"   },   \"tags\" : [     \"eventTag1\"   ],   \"startTime\": 1490000000000,   \"endTime\": 1490000000001 }</pre>
        :return: ResponseContainerEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_event" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerEvent',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_event(self, id, **kwargs):  # noqa: E501
        """Delete a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_event(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_event_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_event_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_event_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_event_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerEvent',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_alert_event_queries_slug(self, id, **kwargs):  # noqa: E501
        """If the specified event is associated with an alert, returns a slug encoding the queries having to do with that alert firing or resolution  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_alert_event_queries_slug(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerString
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_alert_event_queries_slug_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_alert_event_queries_slug_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_alert_event_queries_slug_with_http_info(self, id, **kwargs):  # noqa: E501
        """If the specified event is associated with an alert, returns a slug encoding the queries having to do with that alert firing or resolution  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_alert_event_queries_slug_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerString
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_alert_event_queries_slug" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_alert_event_queries_slug`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event/{id}/alertQueriesSlug', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerString',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_alert_firing_details(self, id, **kwargs):  # noqa: E501
        """Return details of a particular alert firing, including all the series that fired during the referred alert firing  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_alert_firing_details(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id of an event of type alert or alert-detail, used to lookup the particular alert firing (required)
        :return: ResponseContainerSetSourceLabelPair
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_alert_firing_details_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_alert_firing_details_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_alert_firing_details_with_http_info(self, id, **kwargs):  # noqa: E501
        """Return details of a particular alert firing, including all the series that fired during the referred alert firing  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_alert_firing_details_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id of an event of type alert or alert-detail, used to lookup the particular alert firing (required)
        :return: ResponseContainerSetSourceLabelPair
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_alert_firing_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_alert_firing_details`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event/{id}/alertFiringDetails', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerSetSourceLabelPair',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_alert_firing_events(self, alert_id, **kwargs):  # noqa: E501
        """Get firings events of an alert within a time range  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_alert_firing_events(alert_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str alert_id: (required)
        :param int earliest_start_time_epoch_millis:
        :param int latest_start_time_epoch_millis:
        :param int limit:
        :param bool asc:
        :return: ResponseContainerPagedEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_alert_firing_events_with_http_info(alert_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_alert_firing_events_with_http_info(alert_id, **kwargs)  # noqa: E501
            return data

    def get_alert_firing_events_with_http_info(self, alert_id, **kwargs):  # noqa: E501
        """Get firings events of an alert within a time range  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_alert_firing_events_with_http_info(alert_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str alert_id: (required)
        :param int earliest_start_time_epoch_millis:
        :param int latest_start_time_epoch_millis:
        :param int limit:
        :param bool asc:
        :return: ResponseContainerPagedEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['alert_id', 'earliest_start_time_epoch_millis', 'latest_start_time_epoch_millis', 'limit', 'asc']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_alert_firing_events" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'alert_id' is set
        if self.api_client.client_side_validation and ('alert_id' not in params or
                                                       params['alert_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `alert_id` when calling `get_alert_firing_events`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'alert_id' in params:
            query_params.append(('alertId', params['alert_id']))  # noqa: E501
        if 'earliest_start_time_epoch_millis' in params:
            query_params.append(('earliestStartTimeEpochMillis', params['earliest_start_time_epoch_millis']))  # noqa: E501
        if 'latest_start_time_epoch_millis' in params:
            query_params.append(('latestStartTimeEpochMillis', params['latest_start_time_epoch_millis']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'asc' in params:
            query_params.append(('asc', params['asc']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event/alertFirings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerPagedEvent',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_events_with_time_range(self, **kwargs):  # noqa: E501
        """List all the events for a customer within a time range  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_events_with_time_range(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int earliest_start_time_epoch_millis:
        :param int latest_start_time_epoch_millis:
        :param str cursor:
        :param int limit:
        :return: ResponseContainerPagedEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_events_with_time_range_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_events_with_time_range_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_events_with_time_range_with_http_info(self, **kwargs):  # noqa: E501
        """List all the events for a customer within a time range  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_events_with_time_range_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int earliest_start_time_epoch_millis:
        :param int latest_start_time_epoch_millis:
        :param str cursor:
        :param int limit:
        :return: ResponseContainerPagedEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['earliest_start_time_epoch_millis', 'latest_start_time_epoch_millis', 'cursor', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_events_with_time_range" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'earliest_start_time_epoch_millis' in params:
            query_params.append(('earliestStartTimeEpochMillis', params['earliest_start_time_epoch_millis']))  # noqa: E501
        if 'latest_start_time_epoch_millis' in params:
            query_params.append(('latestStartTimeEpochMillis', params['latest_start_time_epoch_millis']))  # noqa: E501
        if 'cursor' in params:
            query_params.append(('cursor', params['cursor']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerPagedEvent',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_event(self, id, **kwargs):  # noqa: E501
        """Get a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_event(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_event_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_event_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_event_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_event_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerEvent',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_event_tags(self, id, **kwargs):  # noqa: E501
        """Get all tags associated with a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_event_tags(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerTagsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_event_tags_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_event_tags_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_event_tags_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get all tags associated with a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_event_tags_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: ResponseContainerTagsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_event_tags" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_event_tags`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event/{id}/tag', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerTagsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_related_events_with_time_span(self, id, **kwargs):  # noqa: E501
        """List all related events for a specific firing event with a time span of one hour  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_related_events_with_time_span(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param bool is_overlapped:
        :param str rendering_method:
        :param int limit:
        :return: ResponseContainerPagedEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_related_events_with_time_span_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_related_events_with_time_span_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_related_events_with_time_span_with_http_info(self, id, **kwargs):  # noqa: E501
        """List all related events for a specific firing event with a time span of one hour  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_related_events_with_time_span_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param bool is_overlapped:
        :param str rendering_method:
        :param int limit:
        :return: ResponseContainerPagedEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'is_overlapped', 'rendering_method', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_related_events_with_time_span" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_related_events_with_time_span`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'is_overlapped' in params:
            query_params.append(('isOverlapped', params['is_overlapped']))  # noqa: E501
        if 'rendering_method' in params:
            query_params.append(('renderingMethod', params['rendering_method']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event/{id}/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerPagedEvent',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_event_tag(self, id, tag_value, **kwargs):  # noqa: E501
        """Remove a tag from a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_event_tag(id, tag_value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str tag_value: (required)
        :return: ResponseContainer
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_event_tag_with_http_info(id, tag_value, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_event_tag_with_http_info(id, tag_value, **kwargs)  # noqa: E501
            return data

    def remove_event_tag_with_http_info(self, id, tag_value, **kwargs):  # noqa: E501
        """Remove a tag from a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_event_tag_with_http_info(id, tag_value, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str tag_value: (required)
        :return: ResponseContainer
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'tag_value']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_event_tag" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `remove_event_tag`")  # noqa: E501
        # verify the required parameter 'tag_value' is set
        if self.api_client.client_side_validation and ('tag_value' not in params or
                                                       params['tag_value'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tag_value` when calling `remove_event_tag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'tag_value' in params:
            path_params['tagValue'] = params['tag_value']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event/{id}/tag/{tagValue}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainer',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_event_tags(self, id, **kwargs):  # noqa: E501
        """Set all tags associated with a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_event_tags(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body:
        :return: ResponseContainer
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_event_tags_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.set_event_tags_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def set_event_tags_with_http_info(self, id, **kwargs):  # noqa: E501
        """Set all tags associated with a specific event  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_event_tags_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body:
        :return: ResponseContainer
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_event_tags" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `set_event_tags`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event/{id}/tag', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainer',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_event(self, id, **kwargs):  # noqa: E501
        """Update a specific event  # noqa: E501

        The following fields are readonly and will be ignored when passed in the request: <code>id</code>, <code>isEphemeral</code>, <code>isUserEvent</code>, <code>runningState</code>, <code>canDelete</code>, <code>canClose</code>, <code>creatorType</code>, <code>createdAt</code>, <code>updatedAt</code>, <code>createdEpochMillis</code>, <code>updatedEpochMillis</code>, <code>updaterId</code>, <code>creatorId</code>, and <code>summarizedEvents</code>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_event(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param Event body: Example Body:  <pre>{   \"name\": \"Event API Example\",   \"annotations\": {     \"severity\": \"info\",     \"type\": \"event type\",     \"details\": \"description\"   },   \"tags\" : [     \"eventTag1\"   ],   \"startTime\": 1490000000000,   \"endTime\": 1490000000001 }</pre>
        :return: ResponseContainerEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_event_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_event_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def update_event_with_http_info(self, id, **kwargs):  # noqa: E501
        """Update a specific event  # noqa: E501

        The following fields are readonly and will be ignored when passed in the request: <code>id</code>, <code>isEphemeral</code>, <code>isUserEvent</code>, <code>runningState</code>, <code>canDelete</code>, <code>canClose</code>, <code>creatorType</code>, <code>createdAt</code>, <code>updatedAt</code>, <code>createdEpochMillis</code>, <code>updatedEpochMillis</code>, <code>updaterId</code>, <code>creatorId</code>, and <code>summarizedEvents</code>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_event_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param Event body: Example Body:  <pre>{   \"name\": \"Event API Example\",   \"annotations\": {     \"severity\": \"info\",     \"type\": \"event type\",     \"details\": \"description\"   },   \"tags\" : [     \"eventTag1\"   ],   \"startTime\": 1490000000000,   \"endTime\": 1490000000001 }</pre>
        :return: ResponseContainerEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/event/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerEvent',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
